@@ -5,7 +5,7 @@
  * libpng license (see LICENSE, in pngcrush.c).
  */
 
-/* Special defines for pngcrush version 1.8.9 */
+/* Special defines for pngcrush version 1.8.10 */
 
 #ifndef PNGCRUSH_H
 #define PNGCRUSH_H
@@ -13,6 +13,9 @@
 #define PNG_READ_SUPPORTED
 #define PNG_WRITE_SUPPORTED
 
+#define PNG_BENIGN_ERRORS_SUPPORTED
+#define PNG_BENIGN_READ_ERRORS_SUPPORTED
+
 /* Do not build stuff we will not use */
 #undef PNG_BUILD_GRAYSCALE_PALETTE_SUPPORTED
 #undef PNG_CONVERT_tIME_SUPPORTED
