@@ -334,6 +334,8 @@ void gen_trees_header()
     fprintf(header,
             "/* header created automatically with -DGEN_TREES_H */\n\n");
 
+    fprintf(header, "#ifndef ZLIB_TREES_H\n#define ZLIB_TREES_H\n\n");
+
     fprintf(header, "local const ct_data static_ltree[L_CODES+2] = {\n");
     for (i = 0; i < L_CODES+2; i++) {
         fprintf(header, "{{%3u},{%3u}}%s", static_ltree[i].Code,
@@ -371,6 +373,8 @@ void gen_trees_header()
                 SEPARATOR(i, D_CODES-1, 10));
     }
 
+    fprintf(header, "#endif /* ZLIB_TREES_H */\n");
+
     fclose(header);
 }
 #endif /* GEN_TREES_H */
